pub trait PartitioningWriter<I = RecordBatch, O = Vec<DataFile>>: Send + 'static {
// Required methods
fn write<'life0, 'async_trait>(
&'life0 mut self,
partition_key: PartitionKey,
input: I,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn close<'async_trait>(
self,
) -> Pin<Box<dyn Future<Output = Result<O>> + Send + 'async_trait>>
where Self: 'async_trait;
}Expand description
A writer that can write data to partitioned tables.
This trait provides methods for writing data with partition keys and closing the writer to retrieve the output.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".